LionDialog class

Constructors

LionDialog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

confirm(BuildContext context, {required String title, required String content, String confirmText = "Confirm", String cancelText = "Cancel", VoidCallback? onConfirm, VoidCallback? onCancel}) → void
show(BuildContext context, {required String title, required String content, String confirmText = "OK", VoidCallback? onConfirm}) → void