AppTheme class

Custom ThemeData based on Lion Web Components design tokens.

Constructors

AppTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

themeData ThemeData
Constructed ThemeData using the above tokens
no setter

Constants

backgroundColor → const Color
fontFamilyBase → const String
fontSizeBody → const double
fontSizeH1 → const double
fontSizeH2 → const double
fontSizeSmall → const double
primaryColor → const Color
secondaryColor → const Color
spacingLG → const double
spacingMD → const double
spacingSM → const double
spacingXL → const double
spacingXS → const double
surfaceColor → const Color
textColorOnPrimary → const Color
textColorPrimary → const Color
textColorSecondary → const Color